#!/bin/sh
#  Name:    common
#  Purpose: Common scripting functions
#  Author:  Ronald Bradford 


#------------------------------------------------------------------------------- 
# Initial Variables
#
[ -z "${TMP_DIR}" ] && TMP_DIR=/tmp
TMP_FILE="${TMP_DIR}/$SCRIPT_NAME.tmp.$$"

HOSTNAME=`hostname`
TIME_PATTERN="+%H:%M:%S"
FATAL="FATAL"
ERROR="ERROR"
WARN="WARN "
INFO="INFO "
DEBUG="DEBUG"

#---------------------------------------------------------------------- leave --
leave() {
  rm -f $TMP_FILE
  exit $1
}

#------------------------------------------------------------------------ log -- 
log() {
  TYPE="$1";shift
  TS=`date $TIME_PATTERN`

  echo "$TS $TYPE $*"
}

#---------------------------------------------------------------------- fatal -- 
fatal () {
  log $FATAL $*
  leave 2
}

#---------------------------------------------------------------------- error -- 
error () {
  log $ERROR $*
  leave 1
}

#----------------------------------------------------------------------- warn -- 
warn() {
  log $WARN $*
}

#----------------------------------------------------------------------- info -- 
info() {
  log $INFO $*
}

#---------------------------------------------------------------------- debug -- 
debug() {
  [ ! -z $DEBUGGING ] && log $DEBUG $*
}
